Class: VagrantPlugins::Pushover::Command

Inherits:
Object
  • Object
show all
Defined in:
lib/vagrant-pushover/command.rb

Instance Method Summary collapse

Instance Method Details

#executeObject



7
8
9
10
11
12
13
14
15
# File 'lib/vagrant-pushover/command.rb', line 7

def execute
  config_file = ::VagrantPlugins::Pushover.config_file
  if config_file.exist?
    @env.ui.info("Vagrant-pushover configuration file (.vagrant/pushover.rb) is already exist. Edit it and set your app token and your key.")
  else
    ::VagrantPlugins::Pushover.write_default_key
    @env.ui.info("Generated vagrant-pushover configuration file (.vagrant/pushover.rb). Edit it and set your app token and your key.")
  end
end